@@ -1,7 +1,7 @@
 package CPAN::Critic::Module::Abstract;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010;
 use strict;
@@ -325,7 +325,7 @@ CPAN::Critic::Module::Abstract - Critic CPAN module abstract
 
 =head1 VERSION
 
-This document describes version 0.06 of CPAN::Critic::Module::Abstract (from Perl distribution CPAN-Critic-Module-Abstract), released on 2015-08-17.
+This document describes version 0.07 of CPAN::Critic::Module::Abstract (from Perl distribution CPAN-Critic-Module-Abstract), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -345,7 +345,7 @@ Dist::Zilla plugin coming shortly.
 
 =head2 critique_cpan_module_abstract(%args) -> [status, msg, result, meta]
 
-{en_US Critic CPAN module abstract}.
+Critic CPAN module abstract.
 
 Arguments ('*' denotes required arguments):
 
@@ -644,7 +644,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/CPAN-Criti
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-CPAN-Critic-Module-Abstract>.
+Source repository is at L<https://github.com/perlancar/perl-CPAN-Critic-Module-Abstract>.
 
 =head1 BUGS
 
